@@ -5,7 +5,7 @@ use warnings;
 package Log::Any;
 
 # ABSTRACT: Bringing loggers and listeners together
-our $VERSION = '1.041'; # TRIAL
+our $VERSION = '1.043'; # TRIAL
 
 use Log::Any::Manager;
 use Log::Any::Proxy::Null;
@@ -77,7 +77,18 @@ sub get_logger {
       defined $params{category} ? delete $params{'category'} : caller;
 
     if ( my $default = delete $params{'default_adapter'} ) {
-        $class->_manager->set_default( $category, $default );
+        my @default_adapter_params = ();
+        if (ref $default eq 'ARRAY') {
+            ($default, @default_adapter_params) = @{ $default };
+        }
+        # Every default adapter is set only for a given logger category.
+        # When another adapter is configured (by using
+        # Log::Any::Adapter->set) for this category, it takes
+        # precedence, but if that adapter is later removed, the default
+        # we set here takes over again.
+        $class->_manager->set_default(
+            $category, $default, @default_adapter_params
+        );
     }
 
     my $adapter = $class->_manager->get_adapter( $category );
@@ -122,7 +133,7 @@ Log::Any - Bringing loggers and listeners together
 
 =head1 VERSION
 
-version 1.041
+version 1.043
 
 =head1 SYNOPSIS
 
@@ -323,13 +334,22 @@ detection methods.
 
 =head2 Setting an alternate default logger
 
-To choose something other than Null as the default, pass it as a parameter when
-loading C<Log::Any>
+When no other adapters are configured for your logger, C<Log::Any> uses
+the C<default_adapter>. To choose something other than Null as the
+default, pass it as a parameter when loading C<Log::Any>
 
     use Log::Any '$log', default_adapter => 'Stderr';
 
 The name of the default class follows the same rules as used by L<Log::Any::Adapter>.
 
+To pass arguments to the default adapter's constructor, use an arrayref:
+
+    use Log::Any '$log', default_adapter => [ 'File' => '/var/log/mylog.log' ];
+
+When a consumer configures their own adapter, the default adapter will be
+overridden. If they later remove their adapter, the default adapter will be
+used again.
+
 =head2 Configuring the proxy
 
 Any parameter passed on the import line or via the C<get_logger> method
@@ -390,25 +410,6 @@ other niceties.
 
 =back
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Bugs / Feature Requests
-
-Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/preaction/Log-Any/issues>.
-You will be notified automatically of any progress on your issue.
-
-=head2 Source Code
-
-This is open source software.  The code repository is available for
-public review and contribution under the terms of the license.
-
-L<https://github.com/preaction/Log-Any>
-
-  git clone https://github.com/preaction/Log-Any.git
-
 =head1 AUTHORS
 
 =over 4
@@ -427,30 +428,6 @@ Doug Bell <preaction@cpan.org>
 
 =back
 
-=head1 CONTRIBUTORS
-
-=for stopwords cm-perl Lucas Kanashiro Maxim Vuets Stephen Thirlwall
-
-=over 4
-
-=item *
-
-cm-perl <cm-perl@users.noreply.github.com>
-
-=item *
-
-Lucas Kanashiro <kanashiro.duarte@gmail.com>
-
-=item *
-
-Maxim Vuets <maxim.vuets@booking.com>
-
-=item *
-
-Stephen Thirlwall <sdt@dr.com>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2016 by Jonathan Swartz, David Golden, and Doug Bell.
