@@ -5,9 +5,10 @@ use warnings;
 package Log::Any::Proxy;
 
 # ABSTRACT: Log::Any generator proxy object
-our $VERSION = '1.041'; # TRIAL
+our $VERSION = '1.043'; # TRIAL
 
 use Log::Any::Adapter::Util ();
+use overload;
 
 sub _default_formatter {
     my ( $cat, $lvl, $format, @params ) = @_;
@@ -15,7 +16,10 @@ sub _default_formatter {
     my @new_params =
       map {
            !defined($_) ? '<undef>'
-          : ref($_)     ? Log::Any::Adapter::Util::dump_one_line($_)
+          : ref($_)     ? (
+	        overload::OverloadedStringify($_) ? "$_"
+	      : Log::Any::Adapter::Util::dump_one_line($_)
+	    )
           : $_
       } @params;
     # Perl 5.22 adds a 'redundant' warning if the number parameters exceeds
@@ -43,6 +47,11 @@ sub new {
     return $self;
 }
 
+sub clone {
+    my $self = shift;
+    return (ref $self)->new( %{ $self }, @_ );
+}
+
 sub init { }
 
 for my $attr (qw/adapter filter formatter prefix/) {
@@ -106,7 +115,7 @@ Log::Any::Proxy - Log::Any generator proxy object
 
 =head1 VERSION
 
-version 1.041
+version 1.043
 
 =head1 SYNOPSIS
 
@@ -123,132 +132,14 @@ version 1.041
         String::Flogger::flog( @args );
     };
 
+    # create a clone with different attributes
+    my $bar_log = $log->clone( prefix => 'bar: ' );
+
 =head1 DESCRIPTION
 
 Log::Any::Proxy objects are what modules use to produce log messages.  They
 construct messages and pass them along to a configured adapter.
 
-=head1 USAGE
-
-=head2 Simple logging
-
-Your library can do simple logging using logging methods corresponding to
-the log levels (or aliases):
-
-=over 4
-
-=item *
-
-trace
-
-=item *
-
-debug
-
-=item *
-
-info (inform)
-
-=item *
-
-notice
-
-=item *
-
-warning (warn)
-
-=item *
-
-error (err)
-
-=item *
-
-critical (crit, fatal)
-
-=item *
-
-alert
-
-=item *
-
-emergency
-
-=back
-
-Pass a string to be logged.  Do not include a newline.
-
-    $log->info("Got some new for you.");
-
-The log string will be transformed via the C<filter> attribute (if any) and
-the C<prefix> (if any) will be prepended. Returns the transformed log string.
-
-B<NOTE>: While you are encouraged to pass a single string to be logged, if
-multiple arguments are passed, they are concatenated with a space character
-into a single string before processing.  This ensures consistency across
-adapters, some of which may support multiple arguments to their logging
-functions (and which concatenate in different ways) and some of which do
-not.
-
-=head2 Advanced logging
-
-Your library can do advanced logging using logging methods corresponding to
-the log levels (or aliases), but with an "f" appended:
-
-=over 4
-
-=item *
-
-tracef
-
-=item *
-
-debugf
-
-=item *
-
-infof (informf)
-
-=item *
-
-noticef
-
-=item *
-
-warningf (warnf)
-
-=item *
-
-errorf (errf)
-
-=item *
-
-criticalf (critf, fatalf)
-
-=item *
-
-alertf
-
-=item *
-
-emergencyf
-
-=back
-
-When these methods are called, the adapter is first checked to see if it is
-logging at that level.  If not, the method returns without logging.
-
-Next, arguments are transformed to a message string via the C<formatter>
-attribute.
-
-The default formatter first checks if the first log argument is a code
-reference.  If so, it will executed and the result used as the formatted
-message. Otherwise, the formatter acts like C<sprintf> with some helpful
-formatting.
-
-Finally, the message string is logged via the simple logging functions,
-which can transform or prefix as described above. The transformed log
-string is then returned.
-
 =head1 ATTRIBUTES
 
 =head2 adapter
@@ -294,27 +185,82 @@ be logged.
 
 The default formatter does the following:
 
-=over 4
-
-=item *
-
-if the first argument is a code reference, it is executed and the result returned
-
-=item *
-
-otherwise, it acts like C<sprintf>, except that undef arguments are changed to C<< <undef> >> and any references or objects are dumped via L<Data::Dumper> (but without newlines).
-
-=back
-
-Numeric levels range from 0 (emergency) to 8 (trace).  Constant functions
-for these levels are available from L<Log::Any::Adapter::Util>.
-
 =head2 prefix
 
 If defined, this string will be prepended to all messages.  It will not
 include a trailing space, so add that yourself if you want.  This is less
 flexible/powerful than L</filter>, but avoids an extra function call.
 
+=head1 USAGE
+
+=head2 Simple logging
+
+Your library can do simple logging using logging methods corresponding to
+the log levels (or aliases):
+
+=for :list * trace
+* debug
+* info (inform)
+* notice
+* warning (warn)
+* error (err)
+* critical (crit, fatal)
+* alert
+* emergency
+
+Pass a string to be logged.  Do not include a newline.
+
+    $log->info("Got some new for you.");
+
+The log string will be transformed via the C<filter> attribute (if any) and
+the C<prefix> (if any) will be prepended. Returns the transformed log string.
+
+B<NOTE>: While you are encouraged to pass a single string to be logged, if
+multiple arguments are passed, they are concatenated with a space character
+into a single string before processing.  This ensures consistency across
+adapters, some of which may support multiple arguments to their logging
+functions (and which concatenate in different ways) and some of which do
+not.
+
+=head2 Advanced logging
+
+Your library can do advanced logging using logging methods corresponding to
+the log levels (or aliases), but with an "f" appended:
+
+=for :list * tracef
+* debugf
+* infof (informf)
+* noticef
+* warningf (warnf)
+* errorf (errf)
+* criticalf (critf, fatalf)
+* alertf
+* emergencyf
+
+When these methods are called, the adapter is first checked to see if it is
+logging at that level.  If not, the method returns without logging.
+
+Next, arguments are transformed to a message string via the C<formatter>
+attribute.
+
+The default formatter first checks if the first log argument is a code
+reference.  If so, it will executed and the result used as the formatted
+message. Otherwise, the formatter acts like C<sprintf> with some helpful
+formatting.
+
+Finally, the message string is logged via the simple logging functions,
+which can transform or prefix as described above. The transformed log
+string is then returned.
+
+=for :list * if the first argument is a code reference, it is executed and the result
+  returned
+* otherwise, it acts like C<sprintf>, except that undef arguments are
+  changed to C<< <undef> >> and any references or objects are dumped via
+  L<Data::Dumper> (but without newlines).
+
+Numeric levels range from 0 (emergency) to 8 (trace).  Constant functions
+for these levels are available from L<Log::Any::Adapter::Util>.
+
 =head1 AUTHORS
 
 =over 4
